@@ -5,7 +5,6 @@ const expect = require('chai').expect
 const checkOutput = require('./helpers/utils').checkOutput
 
 require('chai').should()
-
 const noop = () => {}
 
 describe('Command', () => {
@@ -19,11 +18,11 @@ describe('Command', () => {
         .command('foo <bar> [awesome]', 'my awesome command', yargs => yargs)
       const command = y.getCommandInstance()
       const handlers = command.getCommandHandlers()
-      handlers.foo.demanded.should.include({
+      handlers.foo.demanded.should.deep.include({
         cmd: ['bar'],
         variadic: false
       })
-      handlers.foo.optional.should.include({
+      handlers.foo.optional.should.deep.include({
         cmd: ['awesome'],
         variadic: false
       })
@@ -37,23 +36,34 @@ describe('Command', () => {
           argv.awesome.should.equal('world')
           return done()
         })
-        .argv
+        .parse()
     })
 
-    it('populates outer argv with positional arguments', () => {
+    it('populates outer argv with positional arguments when unknown-options-as-args is not set', () => {
       const argv = yargs('foo hello world')
         .command('foo <bar> [awesome]')
-        .argv
+        .parse()
 
       argv._.should.include('foo')
-      argv.bar.should.equal('hello')
-      argv.awesome.should.equal('world')
+      argv.should.have.property('bar', 'hello')
+      argv.should.have.property('awesome', 'world')
+    })
+
+    it('populates outer argv with positional arguments when unknown-options-as-args is set', () => {
+      const argv = yargs('foo hello world')
+        .command('foo <bar> [awesome]')
+        .parserConfiguration({ 'unknown-options-as-args': true })
+        .parse()
+
+      argv._.should.include('foo')
+      argv.should.have.property('bar', 'hello')
+      argv.should.have.property('awesome', 'world')
     })
 
     it('populates argv with camel-case variants of arguments when possible', () => {
       const argv = yargs('foo hello world')
         .command('foo <foo-bar> [baz-qux]')
-        .argv
+        .parse()
 
       argv._.should.include('foo')
       argv['foo-bar'].should.equal('hello')
@@ -65,7 +75,7 @@ describe('Command', () => {
     it('populates argv with camel-case variants of variadic args when possible', () => {
       const argv = yargs('foo hello world !')
         .command('foo <foo-bar> [baz-qux..]')
-        .argv
+        .parse()
 
       argv._.should.include('foo')
       argv['foo-bar'].should.equal('hello')
@@ -77,16 +87,16 @@ describe('Command', () => {
     it('populates subcommand\'s inner argv with positional arguments', () => {
       yargs('foo bar hello world')
         .command('foo', 'my awesome command', yargs => yargs.command(
-            'bar <greeting> [recipient]',
-            'subcommands are cool',
-            noop,
-            (argv) => {
-              argv._.should.deep.equal(['foo', 'bar'])
-              argv.greeting.should.equal('hello')
-              argv.recipient.should.equal('world')
-            }
-          ))
-        .argv
+          'bar <greeting> [recipient]',
+          'subcommands are cool',
+          noop,
+          (argv) => {
+            argv._.should.deep.equal(['foo', 'bar'])
+            argv.greeting.should.equal('hello')
+            argv.recipient.should.equal('world')
+          }
+        ))
+        .parse()
     })
 
     it('ignores positional args for aliases', () => {
@@ -94,12 +104,12 @@ describe('Command', () => {
         .command(['foo [awesome]', 'wat <yo>'], 'my awesome command')
       const command = y.getCommandInstance()
       const handlers = command.getCommandHandlers()
-      handlers.foo.optional.should.include({
+      handlers.foo.optional.should.deep.include({
         cmd: ['awesome'],
         variadic: false
       })
       handlers.foo.demanded.should.deep.equal([])
-      expect(handlers.wat).to.not.exist
+      expect(handlers.wat).to.equal(undefined)
       command.getCommands().should.deep.equal(['foo', 'wat'])
     })
 
@@ -107,17 +117,81 @@ describe('Command', () => {
       const argv = yargs('foo foo.js --reporter=html')
         .command('foo <file>')
         .default('reporter', 'text')
-        .argv
+        .parse()
       argv.file.should.equal('foo.js')
       argv.reporter.should.equal('html')
     })
+
+    // bug reported by @boneskull during mocha migration.
+    it('does not load config twice when command executed', () => {
+      let parseCount = 0
+      yargs('cmd --config=.foo.json')
+        .command(
+          '$0 [foo..]',
+          'does a thing',
+          yargs =>
+            yargs
+              .option('config', {
+                default: '.foo.json'
+              })
+              .positional('foo', {
+                description: 'bar'
+              })
+              .config('config', filepath => {
+                parseCount++
+                return {}
+              }),
+          argv => {}
+        )
+        .parse()
+      parseCount.should.equal(1)
+    })
+
+    // see: https://github.com/yargs/yargs/issues/1457
+    it('handles -- in conjunction with positional arguments', () => {
+      let called = false
+      const argv = yargs('foo hello world series -- apple banana')
+        .command('foo <bar> [awesome...]', 'my awesome command', noop, (argv2) => {
+          argv2.bar.should.eql('hello')
+          argv2.awesome.should.eql(['world', 'series'])
+          argv2['_'].should.eql(['foo', 'apple', 'banana'])
+          called = true
+        })
+        .parse()
+      argv.bar.should.eql('hello')
+      argv.awesome.should.eql(['world', 'series'])
+      argv['_'].should.eql(['foo', 'apple', 'banana'])
+      called.should.equal(true)
+    })
+
+    // see: https://github.com/yargs/yargs/issues/1457
+    it('continues to support populate-- for commands, post #1457', () => {
+      let called = false
+      const argv = yargs('foo hello world series -- apple banana')
+        .command('foo <bar> [awesome...]', 'my awesome command', noop, (argv2) => {
+          argv2.bar.should.eql('hello')
+          argv2.awesome.should.eql(['world', 'series'])
+          argv2['_'].should.eql(['foo'])
+          argv2['--'].should.eql(['apple', 'banana'])
+          called = true
+        })
+        .parserConfiguration({
+          'populate--': true
+        })
+        .parse()
+      argv.bar.should.eql('hello')
+      argv.awesome.should.eql(['world', 'series'])
+      argv['_'].should.eql(['foo'])
+      argv['--'].should.eql(['apple', 'banana'])
+      called.should.equal(true)
+    })
   })
 
   describe('variadic', () => {
     it('allows required arguments to be variadic', () => {
       const argv = yargs('foo /root file1 file2 file3')
         .command('foo <root> <files..>')
-        .argv
+        .parse()
 
       argv.root.should.equal('/root')
       argv.files.should.deep.equal(['file1', 'file2', 'file3'])
@@ -126,7 +200,7 @@ describe('Command', () => {
     it('allows optional arguments to be variadic', () => {
       const argv = yargs('foo /root file1 file2 file3')
         .command('foo <root> [files..]')
-        .argv
+        .parse()
 
       argv.root.should.equal('/root')
       argv.files.should.deep.equal(['file1', 'file2', 'file3'])
@@ -139,13 +213,13 @@ describe('Command', () => {
           err.should.match(/Not enough non-option arguments/)
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('does not fail if zero optional arguments are provided', () => {
       const argv = yargs('foo /root')
         .command('foo <root> [files...]')
-        .argv
+        .parse()
 
       argv.root.should.equal('/root')
       argv.files.should.deep.equal([])
@@ -154,12 +228,23 @@ describe('Command', () => {
     it('only allows the last argument to be variadic', () => {
       const argv = yargs('foo /root file1 file2')
         .command('foo <root..> <file>')
-        .argv
+        .parse()
 
       argv.root.should.equal('/root')
       argv.file.should.equal('file1')
       argv._.should.include('file2')
     })
+
+    // addresses: https://github.com/yargs/yargs/issues/1246
+    it('allows camel-case, variadic arguments, and strict mode to be combined', () => {
+      const argv = yargs('ls one two three')
+        .command('ls [expandMe...]')
+        .strict()
+        .parse()
+
+      argv.expandMe.should.deep.equal(['one', 'two', 'three'])
+      argv['expand-me'].should.deep.equal(['one', 'two', 'three'])
+    })
   })
 
   describe('missing positional arguments', () => {
@@ -170,7 +255,7 @@ describe('Command', () => {
           err.should.match(/got 1, need at least 2/)
           return done()
         })
-        .argv
+        .parse()
 
       argv.bar.should.equal('hello')
     })
@@ -178,7 +263,7 @@ describe('Command', () => {
     it('does not fail if optional argument is missing', () => {
       const argv = yargs('foo hello')
         .command('foo <bar> [awesome]')
-        .argv
+        .parse()
 
       expect(argv.awesome).to.equal(undefined)
       argv.bar.should.equal('hello')
@@ -509,10 +594,10 @@ describe('Command', () => {
   describe('commandDir', () => {
     it('supports relative dirs', () => {
       const r = checkOutput(() => yargs('--help').wrap(null)
-          .commandDir('fixtures/cmddir')
-          .argv)
-      r.should.have.property('exit').and.be.true
-      r.should.have.property('errors').with.length(0)
+        .commandDir('fixtures/cmddir')
+        .parse())
+      r.exit.should.equal(true)
+      r.errors.length.should.equal(0)
       r.should.have.property('logs')
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'usage [command]',
@@ -520,18 +605,16 @@ describe('Command', () => {
         '  usage dream [command] [opts]  Go to sleep and dream',
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ])
     })
 
     it('supports nested subcommands', () => {
       const r = checkOutput(() => yargs('dream --help').wrap(null)
-          .commandDir('fixtures/cmddir')
-          .argv, [ './command' ])
-      r.should.have.property('exit').and.be.true
-      r.should.have.property('errors').with.length(0)
-      r.should.have.property('logs')
+        .commandDir('fixtures/cmddir')
+        .parse(), [ './command' ])
+      r.exit.should.equal(true)
+      r.errors.length.should.equal(0)
       r.logs[0].split(/\n+/).should.deep.equal([
         'command dream [command] [opts]',
         'Go to sleep and dream',
@@ -542,18 +625,16 @@ describe('Command', () => {
         '  --help     Show help  [boolean]',
         '  --version  Show version number  [boolean]',
         '  --shared   Is the dream shared with others?  [boolean]',
-        '  --extract  Attempt extraction?  [boolean]',
-        ''
+        '  --extract  Attempt extraction?  [boolean]'
       ])
     })
 
     it('supports a "recurse" boolean option', () => {
       const r = checkOutput(() => yargs('--help').wrap(null)
-          .commandDir('fixtures/cmddir', { recurse: true })
-          .argv)
-      r.should.have.property('exit').and.be.true
-      r.should.have.property('errors').with.length(0)
-      r.should.have.property('logs')
+        .commandDir('fixtures/cmddir', { recurse: true })
+        .parse())
+      r.exit.should.equal(true)
+      r.errors.length.should.equal(0)
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'usage [command]',
         'Commands:',
@@ -563,8 +644,7 @@ describe('Command', () => {
         '  usage dream [command] [opts]           Go to sleep and dream',
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ])
     })
 
@@ -573,55 +653,52 @@ describe('Command', () => {
       let pathToFile
       let filename
       const r = checkOutput(() => yargs('--help').wrap(null)
-          .commandDir('fixtures/cmddir', {
-            visit (_commandObject, _pathToFile, _filename) {
-              commandObject = _commandObject
-              pathToFile = _pathToFile
-              filename = _filename
-              return false // exclude command
-            }
-          })
-          .argv)
+        .commandDir('fixtures/cmddir', {
+          visit (_commandObject, _pathToFile, _filename) {
+            commandObject = _commandObject
+            pathToFile = _pathToFile
+            filename = _filename
+            return false // exclude command
+          }
+        })
+        .parse())
       commandObject.should.have.property('command').and.equal('dream [command] [opts]')
       commandObject.should.have.property('desc').and.equal('Go to sleep and dream')
       commandObject.should.have.property('builder')
       commandObject.should.have.property('handler')
       pathToFile.should.contain(require('path').join('test', 'fixtures', 'cmddir', 'dream.js'))
       filename.should.equal('dream.js')
-      r.should.have.property('exit').and.be.true
-      r.should.have.property('errors').with.length(0)
-      r.should.have.property('logs')
+      r.exit.should.equal(true)
+      r.errors.length.should.equal(0)
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ])
     })
 
     it('detects and ignores cyclic dir references', () => {
       const r = checkOutput(() => yargs('cyclic --help').wrap(null)
-          .commandDir('fixtures/cmddir_cyclic')
-          .argv, [ './command' ])
-      r.should.have.property('exit').and.be.true
-      r.should.have.property('errors').with.length(0)
+        .commandDir('fixtures/cmddir_cyclic')
+        .parse(), [ './command' ])
+      r.exit.should.equal(true)
+      r.errors.length.should.equal(0)
       r.should.have.property('logs')
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'command cyclic',
         'Attempts to (re)apply its own dir',
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ])
     })
 
     it('derives \'command\' string from filename when not exported', () => {
       const r = checkOutput(() => yargs('--help').wrap(null)
-          .commandDir('fixtures/cmddir_noname')
-          .argv)
-      r.should.have.property('exit').and.be.true
-      r.should.have.property('errors').with.length(0)
+        .commandDir('fixtures/cmddir_noname')
+        .parse())
+      r.exit.should.equal(true)
+      r.errors.length.should.equal(0)
       r.should.have.property('logs')
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'usage [command]',
@@ -629,8 +706,7 @@ describe('Command', () => {
         '  usage nameless  Command name derived from module filename',
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ])
     })
   })
@@ -654,29 +730,29 @@ describe('Command', () => {
       }
 
       const helpCmd = checkOutput(() => yargs('help cmd')
-          .wrap(null)
-          .command(cmd)
-          .argv, [ './command' ])
+        .wrap(null)
+        .command(cmd)
+        .parse(), [ './command' ])
 
       const cmdHelp = checkOutput(() => yargs('cmd help')
-          .wrap(null)
-          .command(cmd)
-          .argv, [ './command' ])
+        .wrap(null)
+        .command(cmd)
+        .parse(), [ './command' ])
 
       const helpCmdSub = checkOutput(() => yargs('help cmd sub')
-          .wrap(null)
-          .command(cmd)
-          .argv, [ './command' ])
+        .wrap(null)
+        .command(cmd)
+        .parse(), [ './command' ])
 
       const cmdHelpSub = checkOutput(() => yargs('cmd help sub')
-          .wrap(null)
-          .command(cmd)
-          .argv, [ './command' ])
+        .wrap(null)
+        .command(cmd)
+        .parse(), [ './command' ])
 
       const cmdSubHelp = checkOutput(() => yargs('cmd sub help')
-          .wrap(null)
-          .command(cmd)
-          .argv, [ './command' ])
+        .wrap(null)
+        .command(cmd)
+        .parse(), [ './command' ])
 
       const expectedCmd = [
         'command cmd <sub>',
@@ -685,8 +761,7 @@ describe('Command', () => {
         '  command cmd sub  Run the subcommand',
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ]
 
       const expectedSub = [
@@ -694,8 +769,7 @@ describe('Command', () => {
         'Run the subcommand',
         'Options:',
         '  --help     Show help  [boolean]',
-        '  --version  Show version number  [boolean]',
-        ''
+        '  --version  Show version number  [boolean]'
       ]
 
       // no help is output if help isn't last
@@ -718,11 +792,11 @@ describe('Command', () => {
       .env('FUN_DIP')
       .global('stick') // this does not actually need to be global
       .command('eat', 'Adult supervision recommended', yargs => yargs.boolean('powder').exitProcess(false), (argv) => {
-        argv.should.have.property('powder').and.be.true
-        argv.should.have.property('stick').and.equal('yummy')
+        argv.powder.should.equal(true)
+        argv.stick.should.equal('yummy')
       })
       .exitProcess(false)
-      .argv
+      .parse()
   })
 
   // addresses https://github.com/yargs/yargs/issues/514.
@@ -735,7 +809,7 @@ describe('Command', () => {
       .command('bar', 'bar command', (yargs) => {
         output.push('bar')
       })
-      .argv
+      .parse()
 
     output.should.include('bar')
     output.should.not.include('foo')
@@ -783,27 +857,26 @@ describe('Command', () => {
       }, (argv) => {
         argv.should.have.property('someone').and.equal('Pat')
       })
-      .argv
+      .parse()
     argv.should.have.property('someone').and.equal('Pat')
   })
 
   it('allows builder function to parse argv without returning', () => {
     const argv = yargs('yo Jude')
       .command('yo <someone>', 'Send someone a yo', (yargs) => {
-        yargs.argv
+        yargs.parse()
       }, (argv) => {
         argv.should.have.property('someone').and.equal('Jude')
-      })
-      .argv
+      }).parse()
     argv.should.have.property('someone').and.equal('Jude')
   })
 
   it('allows builder function to return parsed argv', () => {
     const argv = yargs('yo Leslie')
-      .command('yo <someone>', 'Send someone a yo', yargs => yargs.argv, (argv) => {
+      .command('yo <someone>', 'Send someone a yo', yargs => yargs.parse(), (argv) => {
         argv.should.have.property('someone').and.equal('Leslie')
       })
-      .argv
+      .parse()
     argv.should.have.property('someone').and.equal('Leslie')
   })
 
@@ -827,16 +900,16 @@ describe('Command', () => {
         commandCalled = true
         argv.should.have.property('someone').and.equal('world')
       })
-      .argv
+      .parse()
     argv.should.have.property('someone').and.equal('world')
-    commandCalled.should.be.true
+    commandCalled.should.equal(true)
   })
 
   describe('positional aliases', () => {
     it('allows an alias to be defined for a required positional argument', () => {
       const argv = yargs('yo bcoe 113993')
         .command('yo <user | email> [ssn]', 'Send someone a yo')
-        .argv
+        .parse()
       argv.user.should.equal('bcoe')
       argv.email.should.equal('bcoe')
       argv.ssn.should.equal(113993)
@@ -848,7 +921,7 @@ describe('Command', () => {
         .command('yo [ssn|sin]', 'Send someone a yo', {}, (_argv) => {
           argv = _argv
         })
-        .argv
+        .parse()
       argv.ssn.should.equal(113993)
       argv.sin.should.equal(113993)
     })
@@ -874,7 +947,7 @@ describe('Command', () => {
           })
           .config('foo')
           .global('foo', false)
-          .argv
+          .parse()
       })
 
       it('loads config for command by default', (done) => {
@@ -884,7 +957,7 @@ describe('Command', () => {
             return done()
           })
           .config('foo')
-          .argv
+          .parse()
       })
     })
 
@@ -897,7 +970,7 @@ describe('Command', () => {
           })
           .implies('foo', 'bar')
           .global('foo', false)
-          .argv
+          .parse()
       })
 
       it('applies conflicts logic for command by default', (done) => {
@@ -908,7 +981,7 @@ describe('Command', () => {
             return done()
           })
           .conflicts('foo', 'bar')
-          .argv
+          .parse()
       })
 
       it('resets conflicts logic for command if global is false', (done) => {
@@ -920,7 +993,7 @@ describe('Command', () => {
           })
           .conflicts('foo', 'bar')
           .global('foo', false)
-          .argv
+          .parse()
       })
 
       it('applies custom checks globally by default', (done) => {
@@ -933,7 +1006,7 @@ describe('Command', () => {
             done()
             return true
           })
-          .argv
+          .parse()
       })
 
       it('resets custom check if global is false', () => {
@@ -944,7 +1017,7 @@ describe('Command', () => {
             checkCalled = true
             return true
           }, false)
-          .argv
+          .parse()
         checkCalled.should.equal(false)
       })
 
@@ -956,7 +1029,7 @@ describe('Command', () => {
             return done()
           })
           .demandOption('bar')
-          .argv
+          .parse()
       })
     })
 
@@ -966,11 +1039,11 @@ describe('Command', () => {
         yargs('hi')
           .command('hi', 'The hi command', (innerYargs) => {
             commandCalled = true
-            innerYargs.getStrict().should.be.false
+            innerYargs.getStrict().should.equal(false)
           })
-        yargs.getStrict().should.be.false
-        yargs.argv // parse and run command
-        commandCalled.should.be.true
+        yargs.getStrict().should.equal(false)
+        yargs.parse() // parse and run command
+        commandCalled.should.equal(true)
       })
 
       it('can be enabled just for a command', () => {
@@ -978,11 +1051,11 @@ describe('Command', () => {
         yargs('hi')
           .command('hi', 'The hi command', (innerYargs) => {
             commandCalled = true
-            innerYargs.strict().getStrict().should.be.true
+            innerYargs.strict().getStrict().should.equal(true)
           })
-        yargs.getStrict().should.be.false
-        yargs.argv // parse and run command
-        commandCalled.should.be.true
+        yargs.getStrict().should.equal(false)
+        yargs.parse() // parse and run command
+        commandCalled.should.equal(true)
       })
 
       it('applies strict globally by default', () => {
@@ -991,11 +1064,11 @@ describe('Command', () => {
           .strict()
           .command('hi', 'The hi command', (innerYargs) => {
             commandCalled = true
-            innerYargs.getStrict().should.be.true
+            innerYargs.getStrict().should.equal(true)
           })
-        yargs.getStrict().should.be.true
-        yargs.argv // parse and run command
-        commandCalled.should.be.true
+        yargs.getStrict().should.equal(true)
+        yargs.parse() // parse and run command
+        commandCalled.should.equal(true)
       })
 
       // address regression introduced in #766, thanks @nexdrew!
@@ -1025,14 +1098,14 @@ describe('Command', () => {
       it('allows a command to override global`', () => {
         let commandCalled = false
         yargs('hi')
-         .strict()
-         .command('hi', 'The hi command', (innerYargs) => {
-           commandCalled = true
-           innerYargs.strict(false).getStrict().should.be.false
-         })
-        yargs.getStrict().should.be.true
-        yargs.argv // parse and run command
-        commandCalled.should.be.true
+          .strict()
+          .command('hi', 'The hi command', (innerYargs) => {
+            commandCalled = true
+            innerYargs.strict(false).getStrict().should.equal(false)
+          })
+        yargs.getStrict().should.equal(true)
+        yargs.parse() // parse and run command
+        commandCalled.should.equal(true)
       })
 
       it('does not fire command if validation fails', (done) => {
@@ -1055,7 +1128,7 @@ describe('Command', () => {
         const argv = yargs('command --foo 1 2')
           .command('command', 'a command')
           .array('foo')
-          .argv
+          .parse()
         argv.foo.should.eql([1, 2])
       })
 
@@ -1064,7 +1137,7 @@ describe('Command', () => {
           .command('command', 'a command')
           .array('foo')
           .global('foo', false)
-          .argv
+          .parse()
         argv.foo.should.eql(1)
       })
 
@@ -1076,7 +1149,7 @@ describe('Command', () => {
             msg.should.match(/Choices: 33, 88/)
             return done()
           })
-          .argv
+          .parse()
       })
     })
 
@@ -1090,7 +1163,7 @@ describe('Command', () => {
             return done()
           })
           .alias('foo', 'bar')
-          .argv
+          .parse()
       })
 
       it('allows global application of alias to be disabled', (done) => {
@@ -1105,7 +1178,7 @@ describe('Command', () => {
             alias: 'bar',
             global: false
           })
-          .argv
+          .parse()
       })
     })
 
@@ -1118,7 +1191,7 @@ describe('Command', () => {
             return done()
           })
           .coerce('foo', arg => arg * 2)
-          .argv
+          .parse()
       })
 
       // addresses https://github.com/yargs/yargs/issues/794
@@ -1145,7 +1218,7 @@ describe('Command', () => {
             return done()
           })
           .default('snuh', 55)
-          .argv
+          .parse()
       })
     })
 
@@ -1215,7 +1288,7 @@ describe('Command', () => {
           argv.foo.should.equal('bar')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('executes default command if undefined positional arguments and only command', (done) => {
@@ -1225,7 +1298,7 @@ describe('Command', () => {
           argv._.should.contain('baz')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('executes default command if defined positional arguments and only command', (done) => {
@@ -1235,7 +1308,7 @@ describe('Command', () => {
           argv.target.should.equal('baz')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('allows $0 as an alias for a default command', (done) => {
@@ -1244,7 +1317,7 @@ describe('Command', () => {
           argv.port.should.equal(9999)
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('does not execute default command if another command is provided', (done) => {
@@ -1255,7 +1328,7 @@ describe('Command', () => {
           argv.foo.should.equal('bar')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('allows default command to be set as alias', (done) => {
@@ -1266,7 +1339,7 @@ describe('Command', () => {
           argv.foo.should.equal('bar')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('allows command to be run when alias is default command', (done) => {
@@ -1277,7 +1350,7 @@ describe('Command', () => {
           argv.foo.should.equal('bar')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('the last default command set should take precedence', (done) => {
@@ -1289,7 +1362,7 @@ describe('Command', () => {
           argv.foo.should.equal('bar')
           return done()
         })
-        .argv
+        .parse()
     })
 
     describe('strict', () => {
@@ -1303,7 +1376,7 @@ describe('Command', () => {
             describe: 'a foo command'
           })
           .strict()
-          .argv
+          .parse()
       })
 
       it('allows default command aliases, when strict mode is enabled', (done) => {
@@ -1318,7 +1391,7 @@ describe('Command', () => {
           .option('foo', {
             describe: 'a foo command'
           })
-          .argv
+          .parse()
       })
     })
   })
@@ -1335,7 +1408,7 @@ describe('Command', () => {
           describe: 'a foo command',
           demand: true
         })
-        .argv
+        .parse()
     })
     called.should.equal(false)
     r.errors.should.match(/Missing required argument/)
@@ -1347,7 +1420,7 @@ describe('Command', () => {
       .command('1', 'numeric command', (yargs) => {
         output.push('1')
       })
-      .argv
+      .parse()
     output.should.include('1')
   })
 
@@ -1402,4 +1475,77 @@ describe('Command', () => {
       }).to.throw(/.*\.usage\(\) description must start with \$0.*/)
     })
   })
+
+  describe('async', () => {
+    // addresses https://github.com/yargs/yargs/issues/510
+    it('fails when the promise returned by the command handler rejects', (done) => {
+      const error = new Error()
+      yargs('foo')
+        .command('foo', 'foo command', noop, (yargs) => Promise.reject(error))
+        .fail((msg, err) => {
+          expect(msg).to.equal(null)
+          expect(err).to.equal(error)
+          done()
+        })
+        .parse()
+    })
+
+    it('succeeds when the promise returned by the command handler resolves', (done) => {
+      const handler = new Promise((resolve, reject) => {
+        setTimeout(() => {
+          return resolve(true)
+        }, 5)
+      })
+      const parsed = yargs('foo hello')
+        .command('foo <pos>', 'foo command', () => {}, (yargs) => handler)
+        .fail((msg, err) => {
+          return done(Error('should not have been called'))
+        })
+        .parse()
+
+      handler.then(called => {
+        called.should.equal(true)
+        parsed.pos.should.equal('hello')
+        return done()
+      })
+    })
+
+    // see: https://github.com/yargs/yargs/issues/1144
+    it('displays error and appropriate help message when handler fails', (done) => {
+      const y = yargs('foo')
+        .command('foo', 'foo command', (yargs) => {
+          yargs.option('bar', {
+            describe: 'bar option'
+          })
+        }, (argv) => {
+          return Promise.reject(Error('foo error'))
+        })
+        .exitProcess(false)
+      // the bug reported in #1144 only happens when
+      // usage.help() is called, this does not occur when
+      // console output is suppressed. tldr; we capture
+      // the log output:
+      let errorLog = ''
+      y._getLoggerInstance().error = (out) => {
+        if (out) errorLog += `${out}\n`
+      }
+      y.parse()
+      // the promise returned by the handler rejects immediately,
+      // so we can wait for a small number of ms:
+      setTimeout(() => {
+        // ensure the appropriate help is displayed:
+        errorLog.should.include('bar option')
+        // ensure error was displayed:
+        errorLog.should.include('foo error')
+        return done()
+      }, 5)
+    })
+  })
+
+  // see: https://github.com/yargs/yargs/issues/1099
+  it('does not coerce number from positional with leading "+"', () => {
+    const argv = yargs.command('$0 <phone>', '', (yargs) => {})
+      .parse('+5550100')
+    argv.phone.should.equal('+5550100')
+  })
 })
