@@ -3,7 +3,8 @@
 
 const checkUsage = require('./helpers/utils').checkOutput
 const expect = require('chai').expect
-const yargs = require('../')
+const english = require('../locales/en.json')
+let yargs = require('../')
 
 require('chai').should()
 
@@ -13,16 +14,18 @@ describe('validation tests', () => {
   })
 
   describe('implies', () => {
+    const implicationsFailedPattern = new RegExp(english['Implications failed:'])
+
     it("fails if '_' populated, and implied argument not set", (done) => {
       yargs(['cat'])
         .implies({
           1: 'foo' // 1 arg in _ means --foo is required
         })
         .fail((msg) => {
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
           return done()
         })
-        .argv
+        .parse()
     })
 
     it("fails if key implies values in '_', but '_' is not populated", (done) => {
@@ -32,28 +35,28 @@ describe('validation tests', () => {
           'foo': 1 // --foo means 1 arg in _ is required
         })
         .fail((msg) => {
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails if either implied argument is not set and displays only failed', (done) => {
       yargs(['-f', '-b'])
-          .implies('f', ['b', 'c'])
-          .fail((msg1) => {
-            yargs(['-f', '-c'])
-                .implies('f', ['b', 'c'])
-                .fail((msg2) => {
-                  msg1.should.match(/f -> c/)
-                  msg1.should.not.match(/f -> b/)
-                  msg2.should.match(/f -> b/)
-                  msg2.should.not.match(/f -> c/)
-                  return done()
-                })
-                .argv
-          })
-          .argv
+        .implies('f', ['b', 'c'])
+        .fail((msg1) => {
+          yargs(['-f', '-c'])
+            .implies('f', ['b', 'c'])
+            .fail((msg2) => {
+              msg1.should.match(/f -> c/)
+              msg1.should.not.match(/f -> b/)
+              msg2.should.match(/f -> b/)
+              msg2.should.not.match(/f -> c/)
+              return done()
+            })
+            .parse()
+        })
+        .parse()
     })
 
     it("fails if --no-foo's implied argument is not set", (done) => {
@@ -62,10 +65,10 @@ describe('validation tests', () => {
           '--no-bar': 'foo' // when --bar is not given, --foo is required
         })
         .fail((msg) => {
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails if a key is set, along with a key that it implies should not be set', (done) => {
@@ -74,10 +77,10 @@ describe('validation tests', () => {
           'bar': '--no-foo' // --bar means --foo cannot be given
         })
         .fail((msg) => {
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails if implied key (with "no" in the name) is not set', () => {
@@ -85,14 +88,14 @@ describe('validation tests', () => {
       yargs('--bar')
         .implies({
           'bar': 'noFoo' // --bar means --noFoo (or --no-foo with boolean-negation disabled) is required
-                         // note that this has nothing to do with --foo
+          // note that this has nothing to do with --foo
         })
         .fail((msg) => {
           failCalled = true
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
         })
-        .argv
-      failCalled.should.be.true
+        .parse()
+      failCalled.should.equal(true)
     })
 
     it('doesn\'t fail if implied key (with "no" in the name) is set', () => {
@@ -100,16 +103,16 @@ describe('validation tests', () => {
       const argv = yargs('--bar --noFoo')
         .implies({
           'bar': 'noFoo' // --bar means --noFoo (or --no-foo with boolean-negation disabled) is required
-                         // note that this has nothing to do with --foo
+          // note that this has nothing to do with --foo
         })
         .fail((msg) => {
           failCalled = true
         })
-        .argv
-      failCalled.should.be.false
-      expect(argv.bar).to.be.true
-      expect(argv.noFoo).to.be.true
-      expect(argv.foo).to.not.exist
+        .parse()
+      failCalled.should.equal(false)
+      expect(argv.bar).to.equal(true)
+      expect(argv.noFoo).to.equal(true)
+      expect(argv.foo).to.equal(undefined)
     })
 
     it('fails if implied key (with "no" in the name) is given when it should not', () => {
@@ -117,14 +120,14 @@ describe('validation tests', () => {
       yargs('--bar --noFoo')
         .implies({
           'bar': '--no-noFoo' // --bar means --noFoo (or --no-foo with boolean-negation disabled) cannot be given
-                              // note that this has nothing to do with --foo
+          // note that this has nothing to do with --foo
         })
         .fail((msg) => {
           failCalled = true
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
         })
-        .argv
-      failCalled.should.be.true
+        .parse()
+      failCalled.should.equal(true)
     })
 
     it('doesn\'t fail if implied key (with "no" in the name) that should not be given is not set', () => {
@@ -132,16 +135,16 @@ describe('validation tests', () => {
       const argv = yargs('--bar')
         .implies({
           'bar': '--no-noFoo' // --bar means --noFoo (or --no-foo with boolean-negation disabled) cannot be given
-                              // note that this has nothing to do with --foo
+          // note that this has nothing to do with --foo
         })
         .fail((msg) => {
           failCalled = true
         })
-        .argv
-      failCalled.should.be.false
-      expect(argv.bar).to.be.true
-      expect(argv.noFoo).to.not.exist
-      expect(argv.foo).to.not.exist
+        .parse()
+      failCalled.should.equal(false)
+      expect(argv.bar).to.equal(true)
+      expect(argv.noFoo).to.equal(undefined)
+      expect(argv.foo).to.equal(undefined)
     })
 
     it('allows key to be specified with option shorthand', (done) => {
@@ -150,38 +153,38 @@ describe('validation tests', () => {
           implies: 'foo'
         })
         .fail((msg) => {
-          msg.should.match(/Implications failed/)
+          msg.should.match(implicationsFailedPattern)
           return done()
         })
-        .argv
+        .parse()
     })
   })
 
   describe('conflicts', () => {
     it('fails if both arguments are supplied', (done) => {
       yargs(['-f', '-b'])
-          .conflicts('f', 'b')
-          .fail((msg) => {
-            msg.should.equal('Arguments f and b are mutually exclusive')
-            return done()
-          })
-          .argv
+        .conflicts('f', 'b')
+        .fail((msg) => {
+          msg.should.equal('Arguments f and b are mutually exclusive')
+          return done()
+        })
+        .parse()
     })
 
     it('fails if argument is supplied along with either conflicting argument', (done) => {
       yargs(['-f', '-b'])
-          .conflicts('f', ['b', 'c'])
-          .fail((msg1) => {
-            yargs(['-f', '-c'])
-                .conflicts('f', ['b', 'c'])
-                .fail((msg2) => {
-                  msg1.should.equal('Arguments f and b are mutually exclusive')
-                  msg2.should.equal('Arguments f and c are mutually exclusive')
-                  return done()
-                })
-                .argv
-          })
-          .argv
+        .conflicts('f', ['b', 'c'])
+        .fail((msg1) => {
+          yargs(['-f', '-c'])
+            .conflicts('f', ['b', 'c'])
+            .fail((msg2) => {
+              msg1.should.equal('Arguments f and b are mutually exclusive')
+              msg2.should.equal('Arguments f and c are mutually exclusive')
+              return done()
+            })
+            .parse()
+        })
+        .parse()
     })
 
     it('should not fail if no conflicting arguments are provided', () => {
@@ -190,7 +193,7 @@ describe('validation tests', () => {
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
     })
 
     it('should not fail if argument with conflict is provided, but not the argument it conflicts with', () => {
@@ -206,23 +209,23 @@ describe('validation tests', () => {
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
     })
 
     it('should not fail if conflicting argument is provided, without argument with conflict', () => {
       yargs(['command', '-b', '-c'])
-          .command('command')
-          .option('f', {
-            describe: 'a foo'
-          })
-          .option('b', {
-            describe: 'a bar'
-          })
-          .conflicts('f', 'b')
-          .fail((msg) => {
-            expect.fail()
-          })
-          .argv
+        .command('command')
+        .option('f', {
+          describe: 'a foo'
+        })
+        .option('b', {
+          describe: 'a bar'
+        })
+        .conflicts('f', 'b')
+        .fail((msg) => {
+          expect.fail()
+        })
+        .parse()
     })
 
     it('allows an object to be provided defining conflicting option pairs', (done) => {
@@ -235,7 +238,7 @@ describe('validation tests', () => {
           msg.should.equal('Arguments s and t are mutually exclusive')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('takes into account aliases when applying conflicts logic', (done) => {
@@ -249,19 +252,19 @@ describe('validation tests', () => {
           msg.should.equal('Arguments s and t are mutually exclusive')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('allows key to be specified with option shorthand', (done) => {
       yargs(['-f', '-b'])
-          .option('f', {
-            conflicts: 'b'
-          })
-          .fail((msg) => {
-            msg.should.equal('Arguments f and b are mutually exclusive')
-            return done()
-          })
-          .argv
+        .option('f', {
+          conflicts: 'b'
+        })
+        .fail((msg) => {
+          msg.should.equal('Arguments f and b are mutually exclusive')
+          return done()
+        })
+        .parse()
     })
 
     it('should fail if alias of conflicting argument is provided', (done) => {
@@ -272,7 +275,7 @@ describe('validation tests', () => {
           msg.should.equal('Arguments f and b are mutually exclusive')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('should fail if alias of argument with conflict is provided', (done) => {
@@ -283,7 +286,28 @@ describe('validation tests', () => {
           msg.should.equal('Arguments f and b are mutually exclusive')
           return done()
         })
-        .argv
+        .parse()
+    })
+
+    function loadLocale (locale) {
+      delete require.cache[require.resolve('../')]
+      yargs = require('../')
+      process.env.LC_ALL = locale
+    }
+
+    it('should use appropriate translation', done => {
+      loadLocale('pirate')
+      try {
+        yargs(['-f', '-b'])
+          .conflicts('f', 'b')
+          .fail(msg => {
+            msg.should.equal('Yon scurvy dogs f and b be as bad as rum and a prudish wench')
+            return done()
+          })
+          .parse()
+      } finally {
+        loadLocale('en_US.UTF-8')
+      }
     })
   })
 
@@ -295,7 +319,7 @@ describe('validation tests', () => {
           msg.should.equal('Not enough non-option arguments: got 0, need at least 1')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails in strict mode with invalid command', (done) => {
@@ -308,7 +332,19 @@ describe('validation tests', () => {
           msg.should.equal('Unknown argument: koala')
           return done()
         })
-        .argv
+        .parse()
+    })
+
+    it('fails in strict mode with extra positionals', (done) => {
+      yargs(['kangaroo', 'jumping', 'fast'])
+        .command('kangaroo <status>', 'kangaroo handlers')
+        .strict()
+        .fail((msg) => {
+          msg.should.equal('Unknown argument: fast')
+          return done()
+        })
+        .parse()
+      expect.fail('no parsing failure')
     })
 
     it('does not fail in strict mode when no commands configured', () => {
@@ -318,7 +354,7 @@ describe('validation tests', () => {
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
       argv._[0].should.equal('koala')
     })
 
@@ -327,7 +363,7 @@ describe('validation tests', () => {
       yargs()
         .command('foo <y>')
         .strict()
-        .parse('foo 99', {x: 33}, (err, argv, output) => {
+        .parse('foo 99', { x: 33 }, (err, argv, output) => {
           expect(err).to.equal(null)
           expect(output).to.equal('')
           argv.y.should.equal(99)
@@ -348,7 +384,7 @@ describe('validation tests', () => {
             })
         })
         .strict()
-        .parse('request get --y=22', {x: 33}, (err, argv, output) => {
+        .parse('request get --y=22', { x: 33 }, (err, argv, output) => {
           expect(err).to.equal(null)
           expect(output).to.equal('')
           argv.y.should.equal(22)
@@ -366,7 +402,7 @@ describe('validation tests', () => {
           msg.should.equal('Missing required argument: b')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails when required arguments are present, but a command is missing', (done) => {
@@ -376,7 +412,7 @@ describe('validation tests', () => {
           msg.should.equal('Not enough non-option arguments: got 0, need at least 1')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails without a message if msg is null', (done) => {
@@ -386,7 +422,7 @@ describe('validation tests', () => {
           expect(msg).to.equal(null)
           return done()
         })
-        .argv
+        .parse()
     })
 
     // address regression in: https://github.com/yargs/yargs/pull/740
@@ -397,7 +433,7 @@ describe('validation tests', () => {
           expect(msg).to.equal('hey! give me a custom exit message')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('interprets min relative to command', () => {
@@ -408,7 +444,7 @@ describe('validation tests', () => {
             failureMsg = msg
           })
         })
-        .argv
+        .parse()
       expect(failureMsg).to.equal('Not enough non-option arguments: got 0, need at least 1')
     })
 
@@ -420,11 +456,74 @@ describe('validation tests', () => {
             failureMsg = msg
           })
         })
-        .argv
+        .parse()
       expect(failureMsg).to.equal('Too many non-option arguments: got 2, maximum of 1')
     })
   })
 
+  describe('requiresArg', () => {
+    it('fails when a required argument value of type number is missing', (done) => {
+      yargs()
+        .option('w', { type: 'number', requiresArg: true })
+        .parse('-w', (err, argv, output) => {
+          expect(err).to.not.equal(undefined)
+          expect(err).to.have.property('message', 'Not enough arguments following: w')
+          return done()
+        })
+    })
+
+    it('fails when a required argument value of type string is missing', (done) => {
+      yargs()
+        .option('w', { type: 'string', requiresArg: true })
+        .parse('-w', (err, argv, output) => {
+          expect(err).to.not.equal(undefined)
+          expect(err).to.have.property('message', 'Not enough arguments following: w')
+          return done()
+        })
+    })
+
+    it('fails when a required argument value of type boolean is missing', (done) => {
+      yargs()
+        .option('w', { type: 'boolean', requiresArg: true })
+        .parse('-w', (err, argv, output) => {
+          expect(err).to.not.equal(undefined)
+          expect(err).to.have.property('message', 'Not enough arguments following: w')
+          return done()
+        })
+    })
+
+    it('fails when a required argument value of type array is missing', (done) => {
+      yargs()
+        .option('w', { type: 'array', requiresArg: true })
+        .parse('-w', (err, argv, output) => {
+          expect(err).to.not.equal(undefined)
+          expect(err).to.have.property('message', 'Not enough arguments following: w')
+          return done()
+        })
+    })
+
+    // see: https://github.com/yargs/yargs/issues/1041
+    it('does not fail if argument with required value is not provided', (done) => {
+      yargs()
+        .option('w', { type: 'number', requiresArg: true })
+        .command('woo')
+        .parse('', (err, argv, output) => {
+          expect(err).to.equal(null)
+          return done()
+        })
+    })
+
+    it('does not fail if argument with required value is not provided to subcommand', (done) => {
+      yargs()
+        .option('w', { type: 'number', requiresArg: true })
+        .command('woo')
+        .parse('woo', (err, argv, output) => {
+          expect(err).to.equal(null)
+          return done()
+        })
+    })
+  })
+
   describe('choices', () => {
     it('fails with one invalid value', (done) => {
       yargs(['--state', 'denial'])
@@ -436,7 +535,7 @@ describe('validation tests', () => {
           ])
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails with one valid and one invalid value', (done) => {
@@ -449,7 +548,7 @@ describe('validation tests', () => {
           ])
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails with multiple invalid values for same argument', (done) => {
@@ -462,7 +561,7 @@ describe('validation tests', () => {
           ])
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails with case-insensitive value', (done) => {
@@ -475,7 +574,7 @@ describe('validation tests', () => {
           ])
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('fails with multiple invalid arguments', (done) => {
@@ -490,7 +589,7 @@ describe('validation tests', () => {
           ])
           return done()
         })
-        .argv
+        .parse()
     })
 
     // addresses: https://github.com/yargs/yargs/issues/849
@@ -512,7 +611,7 @@ describe('validation tests', () => {
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
     })
 
     // addresses: https://github.com/yargs/yargs/issues/849
@@ -533,7 +632,7 @@ describe('validation tests', () => {
           msg.should.equal('Missing required argument: c')
           return done()
         })
-        .argv
+        .parse()
     })
 
     // addresses: https://github.com/yargs/yargs/issues/849
@@ -553,7 +652,7 @@ describe('validation tests', () => {
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
     })
 
     // addresses: https://github.com/yargs/yargs/issues/849
@@ -572,7 +671,7 @@ describe('validation tests', () => {
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
     })
   })
 
@@ -585,7 +684,7 @@ describe('validation tests', () => {
           msg.should.eql('Invalid JSON config file: fake.json')
           return done()
         })
-        .argv
+        .parse()
     })
 
     // see: https://github.com/yargs/yargs/issues/172
@@ -599,72 +698,69 @@ describe('validation tests', () => {
         .fail(() => {
           fail = true
         })
-        .argv
+        .parse()
 
       fail.should.equal(false)
     })
 
     it('should be displayed in the help message', () => {
       const r = checkUsage(() => yargs(['--help'])
-          .config('settings')
-          .help('help')
-          .version(false)
-          .wrap(null)
-          .argv
-        )
+        .config('settings')
+        .help('help')
+        .version(false)
+        .wrap(null)
+        .parse()
+      )
       r.should.have.property('logs').with.length(1)
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'Options:',
         '  --settings  Path to JSON config file',
-        '  --help      Show help  [boolean]',
-        ''
+        '  --help      Show help  [boolean]'
       ])
     })
 
     it('should be displayed in the help message with its default name', () => {
       const checkUsage = require('./helpers/utils').checkOutput
       const r = checkUsage(() => yargs(['--help'])
-            .config()
-            .help('help')
-            .version(false)
-            .wrap(null)
-            .argv
-          )
+        .config()
+        .help('help')
+        .version(false)
+        .wrap(null)
+        .parse()
+      )
       r.should.have.property('logs').with.length(1)
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'Options:',
         '  --config  Path to JSON config file',
-        '  --help    Show help  [boolean]',
-        ''
+        '  --help    Show help  [boolean]'
       ])
     })
 
     it('should allow help message to be overridden', () => {
       const checkUsage = require('./helpers/utils').checkOutput
       const r = checkUsage(() => yargs(['--help'])
-          .config('settings', 'pork chop sandwiches')
-          .help('help')
-          .version(false)
-          .wrap(null)
-          .argv
-        )
+        .config('settings', 'pork chop sandwiches')
+        .help('help')
+        .version(false)
+        .wrap(null)
+        .parse()
+      )
       r.should.have.property('logs').with.length(1)
       r.logs.join('\n').split(/\n+/).should.deep.equal([
         'Options:',
         '  --settings  pork chop sandwiches',
-        '  --help      Show help  [boolean]',
-        ''
+        '  --help      Show help  [boolean]'
       ])
     })
 
     it('outputs an error returned by the parsing function', () => {
       const checkUsage = require('./helpers/utils').checkOutput
       const r = checkUsage(() => yargs(['--settings=./package.json'])
-          .config('settings', 'path to config file', configPath => Error('someone set us up the bomb'))
-          .help('help')
-          .wrap(null)
-          .argv
-        )
+        .config('settings', 'path to config file', configPath => Error('someone set us up the bomb'))
+        .help('help')
+        .wrap(null)
+        .parse()
+      )
 
       r.errors.join('\n').split(/\n+/).should.deep.equal([
         'Options:',
@@ -678,12 +774,12 @@ describe('validation tests', () => {
     it('outputs an error if thrown by the parsing function', () => {
       const checkUsage = require('./helpers/utils').checkOutput
       const r = checkUsage(() => yargs(['--settings=./package.json'])
-          .config('settings', 'path to config file', (configPath) => {
-            throw Error('someone set us up the bomb')
-          })
-          .wrap(null)
-          .argv
-        )
+        .config('settings', 'path to config file', (configPath) => {
+          throw Error('someone set us up the bomb')
+        })
+        .wrap(null)
+        .parse()
+      )
 
       r.errors.join('\n').split(/\n+/).should.deep.equal([
         'Options:',
@@ -716,42 +812,55 @@ describe('validation tests', () => {
     it('does not fail when command with subcommands called', () => {
       yargs('one')
         .command('one', 'level one', yargs => yargs
-            .command('twoA', 'level two A')
-            .command('twoB', 'level two B')
-            .strict()
-            .fail((msg) => {
-              expect.fail()
-            }), (argv) => {
-              argv._[0].should.equal('one')
-            })
-        .argv
+          .command('twoA', 'level two A')
+          .command('twoB', 'level two B')
+          .strict()
+          .fail((msg) => {
+            expect.fail()
+          }), (argv) => {
+          argv._[0].should.equal('one')
+        })
+        .parse()
     })
 
     it('does not fail for hidden options', () => {
       const args = yargs('--foo hey')
         .strict()
-        .option('foo', {boolean: true, describe: false})
+        .option('foo', { boolean: true, describe: false })
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
       args.foo.should.equal(true)
     })
 
     it('does not fail if an alias is provided, rather than option itself', () => {
       const args = yargs('--cat hey')
         .strict()
-        .option('foo', {boolean: true, describe: false})
+        .option('foo', { boolean: true, describe: false })
         .alias('foo', 'bar')
         .alias('bar', 'cat')
         .fail((msg) => {
           expect.fail()
         })
-        .argv
+        .parse()
       args.cat.should.equal(true)
       args.foo.should.equal(true)
       args.bar.should.equal(true)
     })
+
+    it('does not fail when unrecognized option is passed after --', () => {
+      const args = yargs('ahoy ben -- --arrr')
+        .strict()
+        .command('ahoy <matey>', 'piratical courtesy')
+        .option('arrr', { boolean: true, describe: false })
+        .fail((msg) => {
+          expect.fail(msg)
+        })
+        .parse()
+      args.matey.should.equal('ben')
+      args._.should.deep.equal(['ahoy', '--arrr'])
+    })
   })
 
   describe('demandOption', () => {
@@ -762,7 +871,7 @@ describe('validation tests', () => {
           msg.should.equal('Missing required argument: b')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('allows demandOption in option shorthand', (done) => {
@@ -774,23 +883,23 @@ describe('validation tests', () => {
           msg.should.equal('Missing required argument: c')
           return done()
         })
-        .argv
+        .parse()
     })
   })
 
   describe('demandCommand', () => {
     it('should return a custom failure message when too many non-hyphenated arguments are found after a demand count', () => {
       const r = checkUsage(() => yargs(['src', 'dest'])
-          .usage('Usage: $0 [x] [y] [z] {OPTIONS} <src> <dest> [extra_files...]')
-          .demandCommand(0, 1, 'src and dest files are both required', 'too many arguments are provided')
-          .wrap(null)
-          .help(false)
-          .version(false)
-          .argv
-        )
+        .usage('Usage: $0 [x] [y] [z] {OPTIONS} <src> <dest> [extra_files...]')
+        .demandCommand(0, 1, 'src and dest files are both required', 'too many arguments are provided')
+        .wrap(null)
+        .help(false)
+        .version(false)
+        .parse()
+      )
       r.should.have.property('result')
       r.should.have.property('logs').with.length(0)
-      r.should.have.property('exit').and.be.ok
+      r.should.have.property('exit').and.to.equal(true)
       r.result.should.have.property('_').and.deep.equal(['src', 'dest'])
       r.errors.join('\n').split(/\n+/).should.deep.equal([
         'Usage: usage [x] [y] [z] {OPTIONS} <src> <dest> [extra_files...]',
@@ -806,7 +915,7 @@ describe('validation tests', () => {
           msg.should.equal('totes got 1 totes expected 2')
           return done()
         })
-        .argv
+        .parse()
     })
 
     // see: https://github.com/yargs/yargs/pull/438
@@ -817,7 +926,7 @@ describe('validation tests', () => {
           msg.should.equal('totes too many, got 3 totes expected 2')
           return done()
         })
-        .argv
+        .parse()
     })
 
     it('defaults to demanding 1 command', (done) => {
@@ -827,7 +936,7 @@ describe('validation tests', () => {
           msg.should.equal('Not enough non-option arguments: got 0, need at least 1')
           return done()
         })
-        .argv
+        .parse()
     })
   })
 })
